<?php 

$lang['module_name'] = 'Модуль кешування';

$lang['module_actions'] = array(
    // 'acl_action' => 'description'
    'edit_cache' => 'Керування'
);

$lang['module_menu_items'] = array(
//    array('method in admin controller', 'title in menu', 'path to the image. empty - default image', 'acl_action')
    array('index', $lang['module_actions']['edit_cache'], '', 'edit_cache')
);