<?php 

$lang['module_name'] = 'Модуль кэширования';

$lang['display_as'] = array(
    'name' => 'Страница',
    'cache' => 'Кэшировать'
);

$lang['Activate cache'] = 'Включить';
$lang['Activate cache?'] = 'Включить кэш для страниц(ы)?';
$lang['Deactivate cache'] = 'Выключить';
$lang['Deactivate cache?'] = 'Выключить кэш для страниц(ы)?';
$lang['Clear cache'] = 'Очистить кэш';
$lang['Clear cache?'] = 'Очистить кэш для страниц(ы)?';